@@ -1,21 +1,17 @@
-class PuppetLint::Plugins::CheckConditionals < PuppetLint::CheckPlugin
-  # Public: Test the manifest tokens for any selectors embedded within resource
-  # declarations and record a warning for each instance found.
-  #
-  # Returns nothing.
-  check 'selector_inside_resource' do
+# Public: Test the manifest tokens for any selectors embedded within resource
+# declarations and record a warning for each instance found.
+PuppetLint.new_check(:selector_inside_resource) do
+  def check
     resource_indexes.each do |resource|
-      resource_tokens = tokens[resource[:start]..resource[:end]]
-
-      resource_tokens.each do |token|
+      resource[:tokens].each do |token|
         if token.type == :FARROW
           if token.next_code_token.type == :VARIABLE
             unless token.next_code_token.next_code_token.nil?
               if token.next_code_token.next_code_token.type == :QMARK
                 notify :warning, {
-                  :message    => 'selector inside resource block',
-                  :linenumber => token.line,
-                  :column     => token.column,
+                  :message => 'selector inside resource block',
+                  :line    => token.line,
+                  :column  => token.column,
                 }
               end
             end
@@ -24,12 +20,12 @@ class PuppetLint::Plugins::CheckConditionals < PuppetLint::CheckPlugin
       end
     end
   end
+end
 
-  # Public: Test the manifest tokens for any case statements that do not
-  # contain a "default" case and record a warning for each instance found.
-  #
-  # Returns nothing.
-  check 'case_without_default' do
+# Public: Test the manifest tokens for any case statements that do not
+# contain a "default" case and record a warning for each instance found.
+PuppetLint.new_check(:case_without_default) do
+  def check
     case_indexes = []
 
     tokens.each_index do |token_idx|
@@ -55,9 +51,9 @@ class PuppetLint::Plugins::CheckConditionals < PuppetLint::CheckPlugin
 
       unless case_tokens.index { |r| r.type == :DEFAULT }
         notify :warning, {
-          :message    => 'case statement without a default case',
-          :linenumber => case_tokens.first.line,
-          :column     => case_tokens.first.column,
+          :message => 'case statement without a default case',
+          :line    => case_tokens.first.line,
+          :column  => case_tokens.first.column,
         }
       end
     end
